@@ -1,21 +1,22 @@
 /*
-   SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef IMAGESCALINGWIDGET_H
-#define IMAGESCALINGWIDGET_H
-#include <QWidget>
+#pragma once
 #include "messagecomposer_export.h"
+#include <QWidget>
 
 class QComboBox;
 class QAbstractButton;
-namespace Ui {
+namespace Ui
+{
 class ImageScalingWidget;
 }
 
-namespace MessageComposer {
+namespace MessageComposer
+{
 class ImageScalingWidgetPrivate;
 /**
  * @brief The ImageScalingWidget class
@@ -26,7 +27,7 @@ class MESSAGECOMPOSER_EXPORT ImageScalingWidget : public QWidget
     Q_OBJECT
 public:
     explicit ImageScalingWidget(QWidget *parent = nullptr);
-    ~ImageScalingWidget();
+    ~ImageScalingWidget() override;
 
     void loadConfig();
     void writeConfig();
@@ -53,4 +54,3 @@ private:
 };
 }
 
-#endif // IMAGESCALINGWIDGET_H
