@@ -1,17 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef ATTACHMENTUPDATEJOB_H
-#define ATTACHMENTUPDATEJOB_H
+#pragma once
 
+#include "attachmentpart.h"
 #include "messagecore_export.h"
 #include <KJob>
-#include "attachmentpart.h"
 
-namespace MessageCore {
+namespace MessageCore
+{
 /**
  * @brief The AttachmentUpdateJob class
  * @author Laurent Montel <montel@kde.org>
@@ -26,6 +26,7 @@ public:
     void start() override;
     Q_REQUIRED_RESULT AttachmentPart::Ptr originalPart() const;
     Q_REQUIRED_RESULT AttachmentPart::Ptr updatedPart() const;
+
 private:
     //@cond PRIVATE
     class Private;
@@ -33,4 +34,3 @@ private:
 };
 }
 
-#endif // ATTACHMENTUPDATEJOB_H
