@@ -4,18 +4,15 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MIMETREEPARSER_ENUMS_H
-#define MIMETREEPARSER_ENUMS_H
+#pragma once
 
-namespace MimeTreeParser {
+namespace MimeTreeParser
+{
 /**
  * The display update mode: Force updates the display immediately, Delayed updates
  * after some time (150ms by default)
  */
-enum UpdateMode {
-    Force = 0,
-    Delayed
-};
+enum UpdateMode { Force = 0, Delayed };
 
 /** Flags for the encryption state. */
 typedef enum {
@@ -36,4 +33,3 @@ typedef enum {
 } KMMsgSignatureState;
 }
 
-#endif
